#
# rootpassword.py - GUI front end code for setting the root password
#
# Brent Fox <bfox@redhat.com>
#
# Copyright 2002, 2003 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

#!/usr/bin/python2.2

import string
import gtk
import gobject
import libuser
import sys
sys.path.append('/usr/share/redhat-config-rootpassword')

##
## I18N
## 
from rhpl.translate import _, N_
import rhpl.translate as translate
translate.textdomain ("redhat-config-rootpassword")

##
## Icon for windows
##

iconPixbuf = None      
try:
    iconPixbuf = gtk.gdk.pixbuf_new_from_file("/usr/share/redhat-config-rootpassword/pixmaps/root-password.png")
except:
    pass

class childWindow:
    #You must specify a runPriority for the order in which you wish your module to run
    runPriority = 40
    moduleName = _("Root Password")
    moduleClass = "reconfig"
    commentTag = _("Change the root password for the system")

    def destroy(self, args):
        gtk.mainquit()
    
    def __init__(self):
        self.doDebug = None
        self.mainWindow = gtk.Window()
        self.mainWindow.connect("destroy", self.destroy)
        self.mainWindow.set_position(gtk.WIN_POS_CENTER)
        self.mainWindow.set_icon(iconPixbuf)
        self.mainWindow.set_border_width(10)
        self.mainWindow.set_resizable(gtk.FALSE)
        self.toplevel = gtk.VBox(gtk.FALSE)
        self.mainVBox = gtk.VBox(gtk.FALSE)
        self.iconBox = gtk.HBox()
        self.passwordEntry = gtk.Entry()
        self.passwordEntry.set_visibility(gtk.FALSE)
        self.confirmEntry = gtk.Entry()
        self.confirmEntry.set_visibility(gtk.FALSE)

        p = None
        self.icon = None
        try:
            p = gtk.gdk.pixbuf_new_from_file("../pixmaps/root-password.png")
        except:
            try:
                p = gtk.gdk.pixbuf_new_from_file("/usr/share/redhat-config-rootpassword/pixmaps/root-password.png")
            except:
                print "no image found"
                pass

        if p:
            self.icon = gtk.Image()
            self.icon.set_from_pixbuf(p)

        self.title = gtk.Label(_("Root Password"))
        self.title.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse ("white"))

        self.msgLabel = gtk.Label(_("Please set the root password for the system."))
        self.msgLabel.set_line_wrap(gtk.FALSE)
        self.msgLabel.set_alignment(0.0, 0.5)

        self.table = gtk.Table(2, 2)
        label = gtk.Label(_("Root Password:"))
        label.set_alignment(0.0, 0.5)
        self.table.attach(label, 0, 1, 0, 1, gtk.FILL)
        self.table.attach(self.passwordEntry, 1, 2, 0, 1, gtk.SHRINK, gtk.FILL, 5, 5)
        label = gtk.Label(_("Confirm:"))
        label.set_alignment(0.0, 0.5)
        self.table.attach(label, 0, 1, 1, 2, gtk.FILL)
        self.table.attach(self.confirmEntry, 1, 2, 1, 2, gtk.SHRINK, gtk.FILL, 5, 5)

    def okClicked(self, *args):
        result = self.apply()
        if result == 0:
            gtk.mainquit()

    def apply(self, *args):
        passwd1 = self.passwordEntry.get_text()
        passwd2 = self.confirmEntry.get_text()

        if self.doDebug:
            print "don't change root password in debug mode"
            return 0

        if (len(passwd1) < 6) or (len(passwd2) < 6):
            dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK,
                                    (_("Root password must be at least 6 characters in length.")))
            dlg.set_position(gtk.WIN_POS_CENTER)
            dlg.set_modal(gtk.TRUE)
            dlg.set_icon(iconPixbuf)
            dlg.run()
            dlg.destroy()
            self.passwordEntry.set_text("")
            self.confirmEntry.set_text("")
            self.grabFocus()
            return None
        elif passwd1 != passwd2:
            dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK,
                                    (_("Passwords do not match.  Please try again.")))
            dlg.set_position(gtk.WIN_POS_CENTER)
            dlg.set_modal(gtk.TRUE)
            dlg.set_icon(iconPixbuf)
            dlg.run()
            dlg.destroy()
            self.passwordEntry.set_text("")
            self.confirmEntry.set_text("")
            self.grabFocus()
            return None

        if self.doDebug:
            return 0
        
        self.admin = libuser.ADMIN()
        rootEnt = self.admin.lookupUserByName('root')
        self.admin.setpassUser(rootEnt, passwd1, 0)
        return 0

    def setKickstartData(self, kickstartData):
        print "in setKickstartData"
        #Get the lang from the list of languages
        return 0

    def setKickstartDefaults(self, kickstartData):
        pass


    def launch(self, doDebug = None):
        self.doDebug = doDebug

        self.internalVBox = gtk.VBox(gtk.FALSE, 10)
        self.internalVBox.set_border_width(10)

        self.msgLabel.set_size_request(500, -1)
        self.internalVBox.pack_start(self.msgLabel, gtk.FALSE)
        self.internalVBox.pack_start(self.table, gtk.FALSE)
        self.mainVBox.pack_start(self.internalVBox, gtk.TRUE)
        self.passwordEntry.grab_focus()
        return self.mainVBox, self.icon, self.moduleName

    def grabFocus(self):
        self.passwordEntry.grab_focus()

    def stand_alone(self):
        self.mainWindow.set_title(_("Root Password"))
        bb = gtk.HButtonBox()
        bb.set_layout(gtk.BUTTONBOX_END)
        bb.set_spacing(10)
        okButton = gtk.Button(stock='gtk-ok')
        okButton.connect("clicked", self.okClicked)
        cancelButton = gtk.Button(stock='gtk-cancel')
        cancelButton.connect("clicked", self.destroy)

        if self.icon:
            self.iconBox.pack_start(self.icon, gtk.FALSE)
        self.iconBox.pack_start(self.msgLabel, gtk.FALSE)
        self.mainWindow.add(self.toplevel)
        self.mainVBox.set_spacing(10)
        self.toplevel.pack_start(self.iconBox, gtk.FALSE)
        self.toplevel.pack_start(self.mainVBox, gtk.FALSE)
        self.mainVBox.pack_start(self.table, gtk.FALSE)
        self.mainVBox.pack_start(gtk.HSeparator(), gtk.FALSE, 10)
        bb.pack_start(cancelButton)
        bb.pack_start(okButton)
        self.mainVBox.pack_start(bb, gtk.FALSE)

        self.mainWindow.show_all()
        self.passwordEntry.grab_focus()
        gtk.mainloop()
